@@ -1,6 +1,6 @@
 import os
 import shutil
-from os.path import join
+from os.path import join, split
 from pathlib import Path
 from typing import Dict, List, Tuple, Union, Optional
 
@@ -247,7 +247,6 @@ def remove_create(dir_: str, remove=True, logger=None, verbose=1):
     :param verbose:
     :return:
     """
-    import os
     import shutil
 
     if os.path.exists(dir_) and remove:
@@ -259,44 +258,7 @@ def remove_create(dir_: str, remove=True, logger=None, verbose=1):
     raise ValueError("dir_ should be provided!")
 
 
-def mkdir_incremental(dir_path: str, base_name="exp", fix_name=None, overwrite=False) -> Path:
-    """
-    makes new directories, if it exists increment it and makes another one. Good for hyperparameter tuning!
-    Args:
-        dir_path:
-        base_name:
-        fix_name: If provided this will be created!
-        overwrite: If True, it will overwrite the existing directory!
-
-    Returns:
-
-    """
-    os.makedirs(dir_path, exist_ok=True)
-    if overwrite:
-        return Path(dir_path)
-
-    if fix_name is not None:
-        final_path = os.path.join(dir_path, fix_name)
-        os.makedirs(final_path, exist_ok=True)
-    else:
-        folders = []
-        for dir_ in os.listdir(dir_path):
-            if base_name in dir_:
-                counter = dir_.split(base_name + "_")[-1]
-                if counter.isdigit():
-                    folders.append(int(counter))
-        if len(folders) == 0:
-            final_path = os.path.join(dir_path, base_name + f"_1")
-        else:
-            max_counter = max(folders)
-            final_path = os.path.join(
-                dir_path, base_name + f"_{max_counter + 1}")
-        os.makedirs(final_path)
-
-    return Path(final_path)
-
-
-def file_incremental(file_path, artifact_type="prefix", artifact_value=0, extra_punctuation="_",
+def file_incremental(file_path: str, artifact_type="prefix", artifact_value=0, extra_punctuation="_",
                      add_artifact_value=False):
     """
     This function is used to increment a file's address with prefix or suffix values until it becomes unique
@@ -307,18 +269,22 @@ def file_incremental(file_path, artifact_type="prefix", artifact_value=0, extra_
     :param add_artifact_value: If set to True, adds the artifact_value then checks its existence.
     :return:
     """
-    dir_, n = os.path.split(file_path)
+    dir_, filename = os.path.split(file_path)
     artifact_value = int(artifact_value)
     while True:
         if add_artifact_value:
             # Maybe someone requires their file to have the first artifact
-            file_path = join(dir_, split_extension(n, artifact_type=artifact_type, artifact_value=artifact_value,
+            file_path = join(dir_, split_extension(filename,
+                                                   artifact_type=artifact_type,
+                                                   artifact_value=artifact_value,
                                                    extra_punctuation=extra_punctuation))
         if not os.path.exists(file_path):
             break
 
         if not add_artifact_value:
-            file_path = join(dir_, split_extension(n, artifact_type=artifact_type, artifact_value=artifact_value,
+            file_path = join(dir_, split_extension(filename,
+                                                   artifact_type=artifact_type,
+                                                   artifact_value=artifact_value,
                                                    extra_punctuation=extra_punctuation))
         artifact_value += 1
     return file_path
@@ -545,6 +511,16 @@ class DirUtils:
         if mode == "mv" and remove_in_dir:
             shutil.rmtree(in_dir)
 
+    @staticmethod
+    def write_txt(path: str | Path, list_content: list, mode="w"):
+        with open(path, mode=mode) as f:
+            for item in list_content:
+                f.write(f"{item}\n")
+
+    @staticmethod
+    def read_txt(path: str | Path, mode="r"):
+        list_content = [item.strip() for item in open(path, mode=mode).readlines()]
+        return list_content
 
     @staticmethod
     def dir_train_test_split(
@@ -660,13 +636,18 @@ class DirUtils:
                                current_extension=current_extension, )
 
     @staticmethod
-    def list_dir_full_path(directory: str, filter_directories: bool = True,
+    def list_dir_full_path(directory: str,
+                           filter_directories: bool = True,
                            interest_extensions: Optional[Union[str, List[str]]] = None,
                            only_directories: bool = False,
                            get_full_path: bool = True,
                            sort: bool = True,
                            not_exists_is_ok: bool = False,
-                           ) -> List[str]:
+                           dir_depth: int = -1,
+                           exact_depth: bool = False,
+                           return_dict: bool = False,
+                           ends_with:Optional[Union[str, List[str]]] = None,
+                           ) -> Union[List[str], Dict[str, str]]:
         """
         Returns the full path objects in a directory
         :param directory:
@@ -678,32 +659,77 @@ class DirUtils:
         :param sort: If set to True, the directory will be sorted first!
         :param not_exists_is_ok: If set the True, and directory does not exist just returns an empty list,
          otherwise raises error.
+        :param dir_depth: How depth the code should search, default is -1 which means deactivated.
+        Only works when only_directories is set to True.
+        :param exact_depth: If set True, the exact depth should be matched and smaller ones are not accepted!
+        :param return_dict: If return_dict is set to True, the output will be a dict like the following: {filename: filepath}
+        :param ends_with: If ends with these items they will be accepted
         :return:
         """
         interest_extensions = interest_extensions or []
         interest_extensions = [interest_extensions] if isinstance(interest_extensions, str) else interest_extensions
         interest_extensions = [f".{ext}" if not ext.startswith(".") else ext for ext in
                                interest_extensions]
+
         output = []
         if not os.path.exists(directory):
             if not_exists_is_ok:
                 return output
             else:
                 raise ValueError(f"Directory: {directory} does not exist!")
-        for filename in sorted(os.listdir(directory)) if sort else os.listdir(directory):
-            file_path = join(directory, filename)
-            if not only_directories:
-                if filter_directories and os.path.isdir(file_path):
-                    continue
-                if interest_extensions and DirUtils.split_extension(file_path)[1] not in interest_extensions:
-                    continue
-            else:
-                if not os.path.isdir(file_path):
+        if only_directories and dir_depth > 0:
+            directory = "./" if directory == "." else directory
+            for root, dirs, files in os.walk(directory):
+                for dir_name in dirs:
+                    if not DirUtils.endswith(dir_name, ends_with):
+                        continue
+                    current_dir_path = join(directory, root.replace(directory, '').lstrip("//"), dir_name.lstrip("//"))
+                    relative_current_dir_path = join(root.replace(directory, ''), dir_name.lstrip("//"))
+                    current_depth = len(relative_current_dir_path.strip("/").split("/"))
+                    if exact_depth:
+                        if current_depth == dir_depth:
+                            output.append(current_dir_path)
+                    else:
+                        if current_depth <= dir_depth:
+                            output.append(current_dir_path)
+            output = sorted(output) if sort else output
+        else:
+            for filename in sorted(os.listdir(directory)) if sort else os.listdir(directory):
+                if not DirUtils.endswith(filename, ends_with):
                     continue
+                file_path = join(directory, filename)
+                if not only_directories:
+                    if filter_directories and os.path.isdir(file_path):
+                        continue
+                    if interest_extensions and DirUtils.split_extension(file_path)[1] not in interest_extensions:
+                        continue
+                else:
+                    if not os.path.isdir(file_path):
+                        continue
 
-            output.append(file_path if get_full_path else filename)
+                output.append(file_path if get_full_path else filename)
+            output = sorted(output) if sort else output
+            if return_dict:
+                if interest_extensions:
+                    output = {DirUtils.remove_extension_with_replace(split(filepath)[-1], interest_extensions): filepath
+                              for filepath in output}
+                else:
+                    output = {DirUtils.split_extension(split(filepath)[-1])[0]: filepath for filepath in output}
         return output
 
+    @staticmethod
+    def remove_extension_with_replace(filename: str, extensions: list[str]) -> str:
+        """
+        Removes extensions from the input filename
+        :param filename:
+        :param extensions:
+        :return:
+        """
+        for extension in extensions:
+            rev_ext = extension[::-1]
+            filename = filename[::-1].replace(rev_ext, "", 1)[::-1]
+        return filename
+
     @staticmethod
     def remove_create(dir_: str, remove=True, logger=None, verbose=0) -> str:
         """
@@ -730,7 +756,7 @@ class DirUtils:
     @staticmethod
     def crawl_directory_dataset(
             dir_: str,
-            ext_filter: list = None,
+            ext_filter: list | str = None,
             map_labels=False,
             label_map_dict: dict = None,
             logger=None,
@@ -750,6 +776,7 @@ class DirUtils:
         print(f"[INFO] beginning to crawl {dir_}")
         x, y = [], []
         label_map = dict()
+        ext_filter = [ext_filter] if isinstance(ext_filter, str) else ext_filter
         for cls_name in os.listdir(dir_):
             cls_path = join(dir_, cls_name)
             if not os.path.isdir(cls_path):
@@ -842,3 +869,173 @@ class DirUtils:
             skip_transfer=skip_transfer,
             remove_in_dir=remove_in_dir,
         )
+
+    @staticmethod
+    def endswith(filepath: str, ext: list[str] | str):
+        """
+        Checks whether a file ends with a list of strings! If ext is None it will return True!
+        :param filepath:
+        :param ext:
+        :return:
+        """
+        if isinstance(ext, list):
+            for ext_ in ext:
+                if filepath.endswith(ext_):
+                    return True
+            return False
+        elif isinstance(ext, str):
+            return filepath.endswith(ext)
+        elif ext is None:
+            return True
+        else:
+            raise ValueError(f"ext: {ext} is not supported!")
+    @staticmethod
+    def file_incremental(file_path: str | None, artifact_type="prefix", artifact_value=0, extra_punctuation="_",
+                         add_artifact_value=False, dir_items: list[str] | None = None):
+        """
+        This function is used to increment a file's address with prefix or suffix values until it becomes unique
+        :param file_path:
+        :param artifact_type:
+        :param artifact_value:
+        :param extra_punctuation:
+        :param add_artifact_value: If set to True, adds the artifact_value then checks its existence.
+        :param dir_items: list of items
+        :return:
+        """
+        dir_, filename = os.path.split(file_path)
+        artifact_value = int(artifact_value)
+        while True:
+            if add_artifact_value:
+                # Maybe someone requires their file to have the first artifact
+
+                file_path = split_extension(filename,
+                                            artifact_type=artifact_type,
+                                            artifact_value=artifact_value,
+                                            extra_punctuation=extra_punctuation)
+                if not dir_items:
+                    file_path = join(dir_, file_path)
+            if (dir_items and not (file_path in dir_items)) or (not dir_items and not os.path.exists(file_path)):
+                break
+
+            if not add_artifact_value:
+                file_path = split_extension(filename,
+                                            artifact_type=artifact_type,
+                                            artifact_value=artifact_value,
+                                            extra_punctuation=extra_punctuation)
+                if not dir_items:
+                    file_path = join(dir_, file_path)
+            artifact_value += 1
+        return file_path
+
+    @staticmethod
+    def mkdir_incremental(dir_path: str | list[str], base_name="exp", fix_name=None, overwrite=False) -> Path:
+        """
+        makes new directories, if it exists increment it and makes another one. Good for hyperparameter tuning!
+        Args:
+            dir_path:
+            base_name:
+            fix_name: If provided this will be created!
+            overwrite: If True, it will overwrite the existing directory!
+
+        Returns:
+
+        """
+        os.makedirs(dir_path, exist_ok=True)
+        if overwrite:
+            return Path(dir_path)
+
+        if fix_name is not None:
+            final_path = os.path.join(dir_path, fix_name)
+            os.makedirs(final_path, exist_ok=True)
+        else:
+            folders = []
+            for dir_ in (os.listdir(dir_path) if isinstance(dir_path, str) else dir_path):
+                if base_name in dir_:
+                    counter = dir_.split(base_name + "_")[-1]
+                    if counter.isdigit():
+                        folders.append(int(counter))
+            if len(folders) == 0:
+                final_path = os.path.join(dir_path, base_name + f"_1")
+            else:
+                max_counter = max(folders)
+                final_path = os.path.join(
+                    dir_path, base_name + f"_{max_counter + 1}")
+            os.makedirs(final_path)
+
+        return Path(final_path)
+
+    @staticmethod
+    def execute_command(command: str):
+        from subprocess import Popen, PIPE
+        process = Popen(command, stdout=PIPE, stderr=None, shell=True)
+        output = process.communicate()[0]
+        return output.decode()
+
+    @staticmethod
+    def is_windows():
+        if os.name != "posix":
+            return True
+        else:
+            return False
+
+    def split(path: str, depth: int = 1, continuous: bool = False, list_it: bool = False):
+        """
+
+        :param path:
+        :param depth:
+        :param continuous:
+        :return:
+        >>> DirUtils.split("/pooya/ali/saeed/wow.txt", 3)
+        'ali'
+        >>> DirUtils.split("/pooya/ali/saeed/wow.txt", 2)
+        'saeed'
+        >>> DirUtils.split("/pooya/ali/saeed/wow.txt", 1)
+        'wow.txt'
+        >>> DirUtils.split("/pooya/ali/saeed/wow.txt", 2, continuous=True)
+        'saeed/wow.txt'
+        >>> DirUtils.split("/pooya/ali/saeed", 2, continuous=True)
+        'ali/saeed'
+        >>> DirUtils.split("/pooya/ali/saeed", 2, continuous=True, list_it=True)
+        ['ali', 'saeed']
+        >>> DirUtils.split("/pooya/ali/saeed", 0)
+        ['pooya', 'ali', 'saeed']
+        """
+        if depth == 0:
+            outputs = []
+            while path:
+                path, p = split(path)
+                if not p:
+                    break
+                outputs.insert(0, p)
+            return outputs
+        elif depth == 1:
+            import warnings
+            warnings.warn("Use os.path.split(path)[-1] for depth=1 :)")
+            return split(path)[-1]
+        elif depth < 1:
+            raise ValueError("depth should not be lower than 1")
+        else:
+            if not continuous:
+                p = path
+                for _ in range(depth - 1):
+                    p = split(p)[0]
+
+                output = split(p)[-1]
+            else:
+                outputs = []
+                for _ in range(depth):
+                    path, p = split(path)
+                    outputs.insert(0, p)
+                if list_it:
+                    output = outputs
+                else:
+                    output = os.path.join(*outputs)
+            return output
+
+    @staticmethod
+    def get_dir_time(directory: str):
+        return {item.split(" ")[-1]: " ".join( item.split(" ")[-4: -1]) for item in DirUtils.execute_command(f"ls -l {directory}").split("\n") if item}
+mkdir_incremental = DirUtils.mkdir_incremental
+
+if __name__ == '__main__':
+    print() #
