@@ -2,10 +2,18 @@ import json
 from typing import Union
 from pathlib import Path
 
+from deep_utils.utils.decorators.main import method_deprecated
+
 
 class JsonUtils:
+
     @staticmethod
-    def load_json(json_path: Union[str, Path], encoding="utf-8") -> dict:
+    @method_deprecated
+    def load_json(json_path: Union[str, Path], encoding="utf-8") -> dict | list:
+        return JsonUtils.load(json_path=json_path, encoding=encoding)
+
+    @staticmethod
+    def load(json_path: Union[str, Path], encoding="utf-8") -> dict | list:
         """
         loads a json file
         :param json_path: Path to json file to load
@@ -18,7 +26,7 @@ class JsonUtils:
         return json_data
 
     @staticmethod
-    def dump_json(
+    def dump(
             json_path: Union[str, Path], json_object: Union[list, dict], encoding="utf-8", ensure_ascii=True
     ) -> None:
         """
@@ -35,3 +43,10 @@ class JsonUtils:
 
         with open(json_path, mode="w", encoding=encoding) as f:
             json.dump(json_object, f, ensure_ascii=ensure_ascii)
+
+    @staticmethod
+    @method_deprecated
+    def dump_json(
+            json_path: Union[str, Path], json_object: Union[list, dict], encoding="utf-8", ensure_ascii=True
+    ) -> None:
+        JsonUtils.dump(json_path=json_path, json_object=json_object, encoding=encoding, ensure_ascii=ensure_ascii)
