@@ -1,20 +1,27 @@
 from logging import Logger
 from typing import Union, Dict
-from deep_utils.utils.logging_utils import log_print, value_error_log
+from deep_utils.utils.logging_utils.logging_utils import log_print, value_error_log
+import minio
+from os.path import split
 
 
 class MinIOUtils:
     @staticmethod
-    def minio_get(minio_client, bucket_name, object_name, logger: Union[None, Logger]):
+    def get_client(endpoint, access_key, secret_key, secure: bool = True) -> minio.Minio:
+        client = minio.Minio(endpoint, access_key, secret_key, secure=secure)
+        return client
+
+    @staticmethod
+    def get(client, bucket_name, object_name, logger: Union[None, Logger] = None):
         """
-        Get object from minio_client. This function is created for compatibility otherwise no extra functionality provided compared to the main module.
-        :param minio_client:
+        Get object from client. This function is created for compatibility otherwise no extra functionality provided compared to the main module.
+        :param client:
         :param bucket_name:
         :param object_name:
         :param logger:
         :return:
         """
-        obj = minio_client.get_object(bucket_name, object_name)
+        obj = client.get_object(bucket_name, object_name)
         log_print(
             logger=logger,
             message=f"Successfully got object: {object_name} from bucket: {bucket_name}",
@@ -22,19 +29,19 @@ class MinIOUtils:
         return obj
 
     @staticmethod
-    def minio_fget(
-            minio_client, bucket_name, object_name, file_path, logger: Union[None, Logger]
+    def fget(
+            client, bucket_name, object_name, file_path, logger: Union[None, Logger] = None
     ):
         """
-        Get file object from minio_client. This function is created for compatibility otherwise no extra functionality provided compared to the main module.
-        :param minio_client:
+        Get file object from client. This function is created for compatibility otherwise no extra functionality provided compared to the main module.
+        :param client:
         :param bucket_name:
         :param object_name:
         :param file_path: Where to save the file
         :param logger:
         :return:
         """
-        obj = minio_client.fget_object(bucket_name, object_name, file_path)
+        obj = client.fget_object(bucket_name, object_name, file_path)
         log_print(
             logger=logger,
             message=f"Successfully got object: {object_name} from bucket: {bucket_name}",
@@ -42,8 +49,8 @@ class MinIOUtils:
         return obj
 
     @staticmethod
-    def minio_put(
-            minio_client,
+    def put(
+            client,
             bucket_name,
             object_name,
             data,
@@ -52,7 +59,7 @@ class MinIOUtils:
     ):
         """
         put an object inside a bucket
-        :param minio_client:
+        :param client:
         :param bucket_name:
         :param object_name:
         :param data: data-file to be stored in
@@ -60,7 +67,7 @@ class MinIOUtils:
         :param logger: a logger instance
         :return:
         """
-        MinIOUtils.create_bucket(minio_client, bucket_name, create, logger, )
+        MinIOUtils.create_bucket(client, bucket_name, create, logger, )
         try:
             length = len(data.read())
             data.seek(0)
@@ -68,7 +75,7 @@ class MinIOUtils:
         except:
             length = -1
             part_size = data.__sizeof__()
-        result = minio_client.put_object(
+        result = client.put_object(
             bucket_name,
             object_name,
             data,
@@ -82,8 +89,8 @@ class MinIOUtils:
         return result
 
     @staticmethod
-    def minio_fput(
-            minio_client,
+    def fput(
+            client,
             bucket_name,
             object_name,
             file_path,
@@ -92,7 +99,7 @@ class MinIOUtils:
     ):
         """
         put a file inside a bucket
-        :param minio_client:
+        :param client:
         :param bucket_name:
         :param object_name:
         :param file_path: file to be stored in the given bucket
@@ -100,9 +107,9 @@ class MinIOUtils:
         :param logger: a logger instance
         :return:
         """
-        MinIOUtils.create_bucket(minio_client, bucket_name, create, logger)
+        MinIOUtils.create_bucket(client, bucket_name, create, logger)
 
-        result = minio_client.fput_object(
+        result = client.fput_object(
             bucket_name,
             object_name,
             file_path,
@@ -114,21 +121,21 @@ class MinIOUtils:
         return result
 
     @staticmethod
-    def create_bucket(minio_client, bucket_name, create=True, logger=None) -> bool:
+    def create_bucket(client, bucket_name, create=True, logger=None) -> bool:
         """
         This method is used to find the requested bucket and create it in case the user desires it.
         :param bucket_name:
         :param create:
         :param logger:
-        :param minio_client:
+        :param client:
         :return:
         """
-        found = minio_client.bucket_exists(bucket_name)
+        found = client.bucket_exists(bucket_name)
         if found:
             log_print(logger=logger,
                       message=f"Bucket {bucket_name} already exists")
         elif not found and create:
-            minio_client.make_bucket(bucket_name)
+            client.make_bucket(bucket_name)
             log_print(logger=logger,
                       message=f"Successfully Created bucket: {bucket_name}")
         else:
@@ -137,19 +144,19 @@ class MinIOUtils:
         return found
 
     @staticmethod
-    def check_minio_connection(minio_host, status_key="MINIO_STATUS") -> Dict[str, str]:
+    def check_connection(host, status_key="MINIO_STATUS") -> Dict[str, str]:
         import requests
         # check minio
         status = dict()
         try:
-            minio_status = requests.get(f"http://{minio_host}/minio/health/live").ok
-            status[status_key] = "Alive" if minio_status else "Down"
+            status = requests.get(f"http://{host}/minio/health/live").ok
+            status[status_key] = "Alive" if status else "Down"
         except:
             status[status_key] = "Down"
         return status
 
     @staticmethod
-    def _get_minio_policy(bucket_name):
+    def _get_policy(bucket_name):
         policy = {"Statement": [{"Action": ["s3:GetBucketLocation"],
                                  "Effect": "Allow", "Principal": {"AWS": ["*"]},
                                  "Resource": [f"arn:aws:s3:::{bucket_name}"]},
@@ -159,9 +166,41 @@ class MinIOUtils:
         return policy
 
     @staticmethod
-    def make_bucket_public(minio_client, bucket_name, logger=None, verbose=1):
+    def make_bucket_public(client, bucket_name, logger=None, verbose=1):
         import json
-        found = MinIOUtils.create_bucket(minio_client, bucket_name)
+        found = MinIOUtils.create_bucket(client, bucket_name)
         if not found:
-            minio_client.set_bucket_policy(bucket_name, json.dumps(MinIOUtils._get_minio_policy(bucket_name)))
+            client.set_bucket_policy(bucket_name, json.dumps(MinIOUtils._get_policy(bucket_name)))
             log_print(logger=logger, message=f"Successfully Made bucket: {bucket_name} public", verbose=verbose)
+
+    @staticmethod
+    def exists(client: minio.Minio, bucket_name: str, object_name: str):
+
+        prefix, name = split(object_name)
+        if prefix:
+            prefix = prefix + "/"
+            list_of_objects = [item._object_name.replace(prefix, "") for item in
+                               client.list_objects(bucket_name, prefix=prefix, recursive=True)]
+        else:
+            list_of_objects = [item._object_name for item in client.list_objects(bucket_name, recursive=True)]
+        if name in list_of_objects:
+            return True
+        else:
+            return False
+
+    @staticmethod
+    def list(client: minio.Minio, bucket_name: str, object_name: str = "", directory: str = "") -> list[str]:
+        if directory:
+            prefix = directory
+        elif object_name:
+            prefix, name = split(object_name)
+        else:
+            raise ValueError("object_name or directory should be provided!")
+
+        if prefix:
+            prefix = (prefix + "/") if not prefix.endswith("/") else prefix
+            list_of_objects = [item._object_name.replace(prefix, "") for item in
+                               client.list_objects(bucket_name, prefix=prefix, recursive=True)]
+        else:
+            list_of_objects = [item._object_name for item in client.list_objects(bucket_name, recursive=True)]
+        return list_of_objects
