@@ -76,6 +76,29 @@ async def post_form_upload(input_url, data_key: str, upload_file):
 
 class AIOHttpRequests:
 
+    @staticmethod
+    async def put_request(url, data=None, json=None):
+        async with aiohttp.ClientSession() as session:
+            if data is not None:
+                async with session.put(url, data=data) as response:
+                    # Check if the request was successful
+                    if response.status == 200:
+                        result = await response.json()
+                        return result
+                    else:
+                        print("Failed to update data:", response.status)
+                        print("Response text:", await response.text())
+            elif json is not None:
+                async with session.put(url, json=data) as response:
+                    # Check if the request was successful
+                    if response.status == 200:
+                        result = await response.json()
+                        return result
+                    else:
+                        print("Failed to update data:", response.status)
+                        print("Response text:", await response.text())
+
+
     @staticmethod
     async def _encoding(response, encoding: str | None):
         if encoding == "content":
@@ -96,34 +119,40 @@ class AIOHttpRequests:
             files: Optional[List[Dict[str, Any]]] = None,
             ssl: bool = False,
             encoding: Optional[str] = None,
-            json_serialize: Callable = json.dumps
+            json_serialize: Callable = json.dumps,
+            json: dict = None
     ):
         """
         The files should have the following items:
         [{'name': variable_name, 'value': file_content, 'content_type': multipart/form-data||application/vnd.ms-excel||etc,
         }, {...}]
         data or files one of them should be filled!
+        If you want to send a dictionary as json, set the json to True. in that case you cannot send files!
         :param url:
         :param data:
         :param files:
         :param ssl:
         :param encoding:
         :param json_serialize:
+        :param json: json data. Data alone is form format. But if you want to send a dict as json simply pass it to json
         :return:
         """
-        if data is None and files is None:
+        if json is None and data is None and files is None:
             raise ValueError("Both data and files cannot be ")
         async with aiohttp.ClientSession(json_serialize=json_serialize) as session:
-            form_data = aiohttp.FormData()
-            if data is not None:
-                for key, value in data.items():
-                    form_data.add_field(key, str(value))
-            if files is not None:
-                for file_obj in files:
-                    form_data.add_field(file_obj.get("name", "file"), file_obj["value"],
-                                        filename=file_obj.get("filename"),
-                                        content_type=file_obj.get("content_type", 'multipart/form-data'))
-            output = await session.post(url, data=form_data, ssl=ssl)
+            if not json:
+                form_data = aiohttp.FormData()
+                if data is not None:
+                    for key, value in data.items():
+                        form_data.add_field(key, str(value))
+                if files is not None:
+                    for file_obj in files:
+                        form_data.add_field(file_obj.get("name", "file"), file_obj["value"],
+                                            filename=file_obj.get("filename"),
+                                            content_type=file_obj.get("content_type", 'multipart/form-data'))
+                output = await session.post(url, data=form_data, ssl=ssl)
+            else:
+                output = await session.post(url, json=json, ssl=ssl)
             output = await AIOHttpRequests._encoding(output, encoding)
         return output
 
@@ -152,27 +181,37 @@ class RequestsUtils:
         output.raise_for_status()
         return output.json()
 
+    @staticmethod
+    def post(url: str, data: dict[str, Any]):
+        output = requests.post(url, json=data)
+        output.raise_for_status()
+        return output.json()
+
 
 if __name__ == '__main__':
-    async def port():
-        import cv2
-        url = "http://ai.8001.kookaat.ir/predict/single?model_name=word"
-        cropped_img = cv2.imread("/home/ai/Desktop/sample-ocr.png")
-        _, buffer = cv2.imencode('.jpg', cropped_img)
-        file_bytes = buffer.tobytes()
-        files = [{'name': "image", 'value': file_bytes,
-                  # 'content_type': "multipart / form - data | | application / vnd.ms - excel | | etc,
-                  }]
-        data = []
-        output = await AIOHttpRequests.form_post_async(url=url, files=files, encoding="json")
-        print(output)
-        return output
+    print(RequestsUtils.post("http://0.0.0.0:8001/llama", {
+        "messages": [{"role": "user", "content": "Who are you?"}]
+    }))
 
-
-    # url = "http://ai.8001.kookaat.ir/predict/single?model_name=word"
-    # filepath = "/home/ai/Desktop/sample-ocr.png"
-    # output = RequestsUtils.post_file(url, "image", filepath)
-    # print(output)
-    import asyncio
-
-    asyncio.run(port())
+    # async def port():
+    #     import cv2
+    #     url = "http://ai.8001.kookaat.ir/predict/single?model_name=word"
+    #     cropped_img = cv2.imread("/home/ai/Desktop/sample-ocr.png")
+    #     _, buffer = cv2.imencode('.jpg', cropped_img)
+    #     file_bytes = buffer.tobytes()
+    #     files = [{'name': "image", 'value': file_bytes,
+    #               # 'content_type': "multipart / form - data | | application / vnd.ms - excel | | etc,
+    #               }]
+    #     data = []
+    #     output = await AIOHttpRequests.form_post_async(url=url, files=files, encoding="json")
+    #     print(output)
+    #     return output
+    #
+    #
+    # # url = "http://ai.8001.kookaat.ir/predict/single?model_name=word"
+    # # filepath = "/home/ai/Desktop/sample-ocr.png"
+    # # output = RequestsUtils.post_file(url, "image", filepath)
+    # # print(output)
+    # import asyncio
+    #
+    # asyncio.run(port())
