@@ -8,15 +8,14 @@ def easy_argparse(*args):
 
     """
     import argparse
+
     parser = argparse.ArgumentParser()
 
     for arg in args:
         tp = type(arg)
         if tp == dict:
-            name = arg.pop('name')
+            name = arg.pop("name")
             parser.add_argument(name, **arg)
         else:
-            raise TypeError(
-                f"easy_argparse just supports dictionaries"
-            )
+            raise TypeError(f"easy_argparse just supports dictionaries")
     return parser.parse_args()
