@@ -14,7 +14,7 @@ def is_video(ext: str):
 
     """
 
-    allowed_exts = ('.mp4', '.webm', '.ogg', '.avi', '.wmv', '.mkv', '.3gp')
+    allowed_exts = (".mp4", ".webm", ".ogg", ".avi", ".wmv", ".mkv", ".3gp")
     return any((ext.endswith(x) for x in allowed_exts))
 
 
@@ -27,6 +27,7 @@ def tik_tok(func):
     Returns:
 
     """
+
     @wraps(func)
     def _time_it(*args, **kwargs):
         start = time()
@@ -34,6 +35,9 @@ def tik_tok(func):
             return func(*args, **kwargs)
         finally:
             end_ = time()
-            print("time: {:.03f}s, fps: {:.03f}".format(end_ - start, 1 / (end_ - start)))
+            print(
+                "time: {:.03f}s, fps: {:.03f}".format(
+                    end_ - start, 1 / (end_ - start))
+            )
 
     return _time_it
